@@ -1,4 +1,4 @@
-// $Id: logging.h,v 1.5 2003/06/30 23:31:26 ensc Exp $    --*- c++ -*--
+// $Id: logging.h,v 1.6 2004/06/22 10:46:56 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -23,8 +23,13 @@
 
 #include "output.h"
 
-#define LOG(MSG)	writeMsg(MSG, sizeof(MSG)-1)
-#define LOGSTR(MSG)	writeMsg(MSG, strlen(MSG))
+#ifndef S_SPLINT_S
+#  define LOG(MSG)	writeMsg(MSG, sizeof(MSG)-1)
+#  define LOGSTR(MSG)	writeMsg(MSG, strlen(MSG))
+#else
+#  define LOG(MSG)	assert(MSG!=0)
+#  define LOGSTR(MSG)	assert(MSG!=0)
+#endif
 
 #ifdef WITH_LOGGING
 void logDHCPPackage(/*@in@*/char const *buffer, size_t len,
